==> forge-1.17.1-1.1.1.tar.gz: totem_of_reviving/src/main/java/com/micle/totemofreviving/items/StrawTotemItem.java <==
package com.micle.totemofreviving.items;

import com.micle.totemofreviving.TotemOfReviving;
import com.micle.totemofreviving.network.C2SRequestPlayerRevive;
import com.micle.totemofreviving.network.C2SRequestTotemCharge;
import com.micle.totemofreviving.network.C2SRequestTotemTarget;
import com.mojang.blaze3d.platform.InputConstants;
import net.minecraft.ChatFormatting;
import net.minecraft.client.KeyMapping;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.TextComponent;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.InteractionResultHolder;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.*;
import net.minecraft.world.level.Level;
import net.minecraftforge.api.distmarker.Dist;
import net.minecraftforge.api.distmarker.OnlyIn;

import java.util.List;

public class StrawTotemItem extends Item {
    public static final String TAG_CHARGE_AMOUNT = "charge";
    public static final String TAG_TARGET_INDEX = "target_index";
    public static final String TAG_TARGET_NAME = "target_name";
    public static final String TAG_FAIL_CHANCE = "fail_chance";
    public static final int STARTING_FAIL_CHANCE = 45;
    private static final KeyMapping KEY_LSHIFT = new KeyMapping("StrawTotemItem_LSHIFT", InputConstants.KEY_LSHIFT, KeyMapping.CATEGORY_INTERFACE);

    public StrawTotemItem() {
        super(new Item.Properties().tab(CreativeModeTab.TAB_MISC).stacksTo(1).rarity(Rarity.UNCOMMON));
    }

    @Override
    public void appendHoverText(ItemStack stack, Level world, List<Component> tooltip, TooltipFlag flag) {
        super.appendHoverText(stack, world, tooltip, flag);
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Charges: " + ChatFormatting.GRAY + stack.getOrCreateTag().getInt(TAG_CHARGE_AMOUNT)));
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Target: " + ChatFormatting.GRAY + stack.getOrCreateTag().getString(TAG_TARGET_NAME)));
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Fail Chance: " + ChatFormatting.GRAY + stack.getOrCreateTag().getInt(TAG_FAIL_CHANCE)));
        tooltip.add(new TextComponent( ChatFormatting.DARK_GRAY + "" + ChatFormatting.ITALIC + "\"Feels kinda funky.\""));
        tooltip.add(new TextComponent(""));
        if (KEY_LSHIFT.isDown()) {
            tooltip.add(new TextComponent(ChatFormatting.YELLOW + "R-CLICK"));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "When other hand is empty: attempt to revive target."));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "When other hand has " + ChatFormatting.GRAY + "Straw Reviving Charge" + ChatFormatting.GOLD + ": charge totem."));
            tooltip.add(new TextComponent(""));
            tooltip.add(new TextComponent(ChatFormatting.YELLOW + "SHIFT R-CLICK"));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "Cycle through available targets."));
        } else {
            tooltip.add(new TextComponent(ChatFormatting.GRAY + "[" + ChatFormatting.WHITE + "LSHIFT" + ChatFormatting.GRAY + "] for advanced tooltip."));
        }
    }

    @Override
    public void onCraftedBy(ItemStack stack, Level world, Player player) {
        super.onCraftedBy(stack, world, player);
        stack.getOrCreateTag().putInt(TAG_CHARGE_AMOUNT, 0);
        stack.getOrCreateTag().putInt(TAG_FAIL_CHANCE, STARTING_FAIL_CHANCE);
    }

    @Override
    @OnlyIn(Dist.CLIENT)
    public InteractionResultHolder<ItemStack> use(Level world, Player player, InteractionHand hand) {
        if (!world.isClientSide) { return super.use(world, player, hand); }
        if (player.isCrouching()) {
            TotemOfReviving.INSTANCE.sendToServer(new C2SRequestTotemTarget(player.getUUID(), hand));
        } else {
            InteractionHand item_charge_hand = InteractionHand.MAIN_HAND;
            if (hand.equals(InteractionHand.MAIN_HAND)) {
                item_charge_hand = InteractionHand.OFF_HAND;
            }
            Item item_charge = player.getItemInHand(item_charge_hand).getItem();

            if (item_charge instanceof StrawChargeItem) {
                TotemOfReviving.INSTANCE.sendToServer(new C2SRequestTotemCharge(player.getUUID(), hand, item_charge_hand));
            } else {
                TotemOfReviving.INSTANCE.sendToServer(new C2SRequestPlayerRevive(player.getUUID(), hand));
            }
        }
        return super.use(world, player, hand);
    }
}

==> forge-1.17.1-1.1.2.tar.gz: totem_of_reviving/src/main/java/com/micle/totemofreviving/items/StrawTotemItem.java <==
package com.micle.totemofreviving.items;

import com.micle.totemofreviving.TotemOfReviving;
import com.micle.totemofreviving.network.C2SRequestPlayerRevive;
import com.micle.totemofreviving.network.C2SRequestTotemCharge;
import com.micle.totemofreviving.network.C2SRequestTotemTarget;
import com.micle.totemofreviving.setup.ModKeyMappings;
import com.mojang.blaze3d.platform.InputConstants;
import net.minecraft.ChatFormatting;
import net.minecraft.client.KeyMapping;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.TextComponent;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.InteractionResultHolder;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.item.*;
import net.minecraft.world.level.Level;
import net.minecraftforge.api.distmarker.Dist;
import net.minecraftforge.api.distmarker.OnlyIn;

import java.util.List;

public class StrawTotemItem extends Item {
    public static final String TAG_CHARGE_AMOUNT = "charge";
    public static final String TAG_TARGET_INDEX = "target_index";
    public static final String TAG_TARGET_NAME = "target_name";
    public static final String TAG_FAIL_CHANCE = "fail_chance";
    public static final int STARTING_FAIL_CHANCE = 45;

    public StrawTotemItem() {
        super(new Item.Properties().tab(CreativeModeTab.TAB_MISC).stacksTo(1).rarity(Rarity.UNCOMMON));
    }

    @Override
    @OnlyIn(Dist.CLIENT)
    public void appendHoverText(ItemStack stack, Level world, List<Component> tooltip, TooltipFlag flag) {
        super.appendHoverText(stack, world, tooltip, flag);
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Charges: " + ChatFormatting.GRAY + stack.getOrCreateTag().getInt(TAG_CHARGE_AMOUNT)));
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Target: " + ChatFormatting.GRAY + stack.getOrCreateTag().getString(TAG_TARGET_NAME)));
        tooltip.add(new TextComponent(ChatFormatting.GOLD + "Fail Chance: " + ChatFormatting.GRAY + stack.getOrCreateTag().getInt(TAG_FAIL_CHANCE)));
        tooltip.add(new TextComponent( ChatFormatting.DARK_GRAY + "" + ChatFormatting.ITALIC + "\"Feels kinda funky.\""));
        tooltip.add(new TextComponent(""));
        if (ModKeyMappings.KEYMAP_UI_LSHIFT.isDown()) {
            tooltip.add(new TextComponent(ChatFormatting.YELLOW + "R-CLICK"));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "When other hand is empty: attempt to revive target."));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "When other hand has " + ChatFormatting.GRAY + "Straw Reviving Charge" + ChatFormatting.GOLD + ": charge totem."));
            tooltip.add(new TextComponent(""));
            tooltip.add(new TextComponent(ChatFormatting.YELLOW + "SHIFT R-CLICK"));
            tooltip.add(new TextComponent(ChatFormatting.GOLD + "Cycle through available targets."));
        } else {
            tooltip.add(new TextComponent(ChatFormatting.GRAY + "[" + ChatFormatting.WHITE + "LSHIFT" + ChatFormatting.GRAY + "] for advanced tooltip."));
        }
    }

    @Override
    public void onCraftedBy(ItemStack stack, Level world, Player player) {
        super.onCraftedBy(stack, world, player);
        stack.getOrCreateTag().putInt(TAG_CHARGE_AMOUNT, 0);
        stack.getOrCreateTag().putInt(TAG_FAIL_CHANCE, STARTING_FAIL_CHANCE);
    }

    @Override
    @OnlyIn(Dist.CLIENT)
    public InteractionResultHolder<ItemStack> use(Level world, Player player, InteractionHand hand) {
        if (!world.isClientSide) { return super.use(world, player, hand); }
        if (player.isCrouching()) {
            TotemOfReviving.INSTANCE.sendToServer(new C2SRequestTotemTarget(player.getUUID(), hand));
        } else {
            InteractionHand item_charge_hand = InteractionHand.MAIN_HAND;
            if (hand.equals(InteractionHand.MAIN_HAND)) {
                item_charge_hand = InteractionHand.OFF_HAND;
            }
            Item item_charge = player.getItemInHand(item_charge_hand).getItem();

            if (item_charge instanceof StrawChargeItem) {
                TotemOfReviving.INSTANCE.sendToServer(new C2SRequestTotemCharge(player.getUUID(), hand, item_charge_hand));
            } else {
                TotemOfReviving.INSTANCE.sendToServer(new C2SRequestPlayerRevive(player.getUUID(), hand));
            }
        }
        return super.use(world, player, hand);
    }
}
